@@ -1,6 +1,6 @@
-use strum_macros::EnumIter;
+use strum::{Display, EnumIter, EnumString};
 
-#[derive(Debug, Clone, EnumIter)]
+#[derive(Debug, Clone, EnumIter, Display, EnumString)]
 pub enum SpinnerNames {
     Dots,
     Dots2,
